import React, {Component} from 'react'
import PropTypes from 'prop-types'
import { Modal, notification } from 'antd'
import { SnippetsOutlined } from '@ant-design/icons'

import MenuUtils from '@/utils/utils-custom.js'
import asyncComponent from '@/utils/asyncComponent'
// import './index.scss'

const PasteForm = asyncComponent(() => import('@/templates/zshare/pasteform'))

class PasteGroup extends Component {
  static propTpyes = {
    Tab: PropTypes.any,         // 标签
    insert: PropTypes.func
  }

  state = {
    visible: false
  }

  resetconfig = (item, appType) => {
    if (item.type === 'tabs') {
      item.uuid = MenuUtils.getuuid()
      item.setting.name = item.setting.name + MenuUtils.getSignName()
      item.name = item.setting.name
      
      item.subtabs.forEach(tab => {
        tab.uuid = MenuUtils.getuuid()

        tab.components = tab.components.map(cell => {
          cell = this.resetconfig(cell, appType)
          return cell
        })
      })
    } else if (item.type === 'group') {
      item.uuid = MenuUtils.getuuid()
      item.setting.name = item.setting.name + MenuUtils.getSignName()
      item.name = item.setting.name

      item.components = item.components.map(cell => {
        cell = MenuUtils.resetComponentConfig(cell, appType)

        return cell
      })
    } else {
      item = MenuUtils.resetComponentConfig(item, appType)
    }

    return item
  }

  pasteSubmit = () => {
    const { Tab } = this.props
    let appType = sessionStorage.getItem('appType')
    let options = ['tabs', 'group', 'datacard', 'propcard', 'timeline', 'balcony', 'normaltable', 'mainsearch', 'simpleform', 'stepform', 'tabform', 'editor', 'tablecard', 'line', 'bar', 'pie', 'scatter', 'sandbox']
    let types = {
      login: '登录',
      navbar: '导航栏',
      topbar: '导航栏'
    }

    if (appType === 'mob') {
      options.push('menubar')
    } else {
      options.push('editable', 'antvG6', 'tree', 'dashboard', 'chart')
    }

    this.pasteFormRef.handleConfirm().then(res => {
      if (res.copyType && types[res.copyType]) {
        notification.warning({
          top: 92,
          message: '分组中不可添加《' + types[res.copyType] + '》组件！',
          duration: 5
        })
        return
      } else if (!options.includes(res.copyType)) {
        notification.warning({
          top: 92,
          message: '配置信息格式错误！',
          duration: 5
        })
        return
      }

      res = this.resetconfig(res, appType)

      delete res.copyType
      
      this.props.insert(res, Tab)

      this.setState({visible: false})

      notification.success({
        top: 92,
        message: '粘贴成功！',
        duration: 2
      })
    })
  }

  render() {
    const { visible } = this.state

    return (
      <div style={{display: 'inline-block'}}>
        <SnippetsOutlined style={{color: 'purple'}} onClick={() => {this.setState({visible: true})}} />
        <Modal
          title="粘贴"
          visible={visible}
          width={600}
          maskClosable={false}
          onOk={this.pasteSubmit}
          onCancel={() => {this.setState({visible: false})}}
          destroyOnClose
        >
          <PasteForm wrappedComponentRef={(inst) => this.pasteFormRef = inst} inputSubmit={this.pasteSubmit}/>
        </Modal>
      </div>
    )
  }
}

export default PasteGroup